@@ -21,6 +21,7 @@ def webui_app(request):
 
 def route_mapping():
     return (
+        ('/jquery.js', jquery),
         ('/load', load_app),
         ('/update', update_app),
         ('/unload', unload_app),
@@ -71,6 +72,15 @@ def get_apps(request):
     return html.render('applications.html', resp)
     # return html.header() + html.applications(resp) + html.footer()
 
+def jquery(request):
+    import os
+    from paxd import PROJECT_PATH
+    from mako.lookup import TemplateLookup
+    
+    path = os.path.join(PROJECT_PATH, 'paxd/webuiapp/templates/jquery-1.5.min.js')
+    with open(path) as f:
+        return f.read()
+
 def load_app(request):
     redis = Redis('localhost')
     
